pub struct EvidenceLaneInventory {
pub lane: EvidenceLane,
pub owner: &'static str,
pub canonical_projection: &'static str,
}Expand description
Existing owner and canonical projection for an evidence lane.
Fields
lane: EvidenceLaneStable lane.
owner: &'static strCrate or product contract that owns the typed source record.
canonical_projection: &'static strSemantic projection used by a future capture.