Module fidelity

Module fidelity 

Fidelity badges recording how faithfully a profile realizes an organ.

Structs

FidelityBadge
A fidelity badge: how faithfully a subject realizes a named badge, at a given level, with a reference to the evidence behind it.

Functions

fidelity_badge_class_symbol
Class symbol for the standard/FidelityBadge runtime object.