pub struct ConformanceHarness { /* private fields */ }Expand description
Registry of conformance tests grouped by the organ they cover.
Implementations
Sourceimpl ConformanceHarness
impl ConformanceHarness
Sourcepub fn register_test(&mut self, test: ConformanceTestCase)
pub fn register_test(&mut self, test: ConformanceTestCase)
Register test under its organ.
Sourcepub fn tests_for_organ(&self, organ: &Symbol) -> &[ConformanceTestCase]
pub fn tests_for_organ(&self, organ: &Symbol) -> &[ConformanceTestCase]
Tests registered for organ, or an empty slice if none.
Sourcepub fn test_count(&self) -> usize
pub fn test_count(&self) -> usize
Total number of registered tests across all organs.
Sourcepub fn with_supported_scenario_lanes(
self,
lanes: impl IntoIterator<Item = ScenarioObservationLane>,
) -> Self
pub fn with_supported_scenario_lanes( self, lanes: impl IntoIterator<Item = ScenarioObservationLane>, ) -> Self
Restrict the scenario observation lanes supported by this harness.
Sourcepub fn register_scenario(
&mut self,
scenario: CharacterizationScenario,
) -> Result<()>
pub fn register_scenario( &mut self, scenario: CharacterizationScenario, ) -> Result<()>
Register one uniquely identified characterization scenario.