Module install

Module install 

Installing language profiles into a profile registry and publishing claims.

Structs

StandardInstallReport
Summary returned by install_profile_stub: the installed profile symbol and its organ and conformance-test counts.

Functions

install_profile_stub
Install profile into registry and publish its claims, gated on standard_install_capability.
standard_install_op_key
Operation key for the standard install operation.