Module lisp

Module lisp 

Symbols exposed by the standard distribution on the lisp codec surface.

Functions

lisp_stub_symbols
The full set of symbols the standard distribution exposes on the lisp codec surface (profile, fidelity, diff, install, test, and organ queries).
standard_fidelity_symbol
Lisp-surface symbol naming the standard fidelity entry point.
standard_profile_symbol
Lisp-surface symbol naming the standard profile entry point.