pub enum SourceExpectation {
LowersTo(String),
ExpectedGap {
code: Symbol,
reason: String,
},
}Expand description
Expected outcome for a source-level conformance case.
Variants
LowersTo(String)
The source lowers to the described shared expression form.
ExpectedGap
The source is an explicit known gap with a machine-readable code.