Module polyglot

Module polyglot 

Polyglot profile functions callable across language profiles.

Structs

ProfileFunction
A callable runtime object owned by a profile and scoped to an organ.
ProfileFunctionBinding
A function registered in a SharedOrganRuntime, with its owning profile, organ, name, and callable value.
SharedOrganRuntime
Runtime sharing organ functions across profiles: profiles may call a function defined by another profile only when both use the function’s organ.

Functions

profile_function_value
Wrap body as a callable ProfileFunction runtime value.

Type Aliases

ProfileFunctionBody
Body of a ProfileFunction: a callable closure over Cx and Args.