Fidelity badges recording how faithfully a profile realizes an organ.
Structs
- Fidelity
Badge - A fidelity badge: how faithfully a subject realizes a named badge, at a given level, with a reference to the evidence behind it.
Functions
- fidelity_
badge_ class_ symbol - Class symbol for the
standard/FidelityBadgeruntime object.