Installing language profiles into a profile registry and publishing claims.
Structs
- Standard
Install Report - Summary returned by
install_profile_stub: the installed profile symbol and its organ and conformance-test counts.
Functions
- install_
profile_ stub - Install
profileintoregistryand publish its claims, gated onstandard_install_capability. - standard_
install_ op_ key - Operation key for the standard install operation.